Welcome to Enaml
================

Enaml is a programming language and framework for creating professional quality
user interfaces with minimal effort. Enaml combines a domain specific declarative language with a constraints based layout system to allow users to easily define
rich UIs with complex and flexible layouts. Enaml applications can be run on any
platform which supports Python and Qt.

A few highlights of the framework:

* A declarative language which extends the grammar of Python
* A set of operators which automatically track runtime dependencies
* A layout system which uses symbolic constraint declarations
* A design which encourages model-view separation
* A well documented and easy to follow code base

See `the docs <http://nucleic.github.io/enaml/docs>`_ for more information.

`Ask questions <http://groups.google.com/d/forum/enaml>`_ on the Q&A forum.

For version information, see `the Revision History <https://github.com/nucleic/enaml/blob/master/releasenotes.rst>`_.
